@@ -1,6 +1,6 @@
 package Net::CLI::Interact::Phrasebook;
-BEGIN {
-  $Net::CLI::Interact::Phrasebook::VERSION = '1.111590';
+{
+  $Net::CLI::Interact::Phrasebook::VERSION = '1.112190';
 }
 
 use Moose;
@@ -35,7 +35,7 @@ sub _build_library {
 }
 
 has 'add_library' => (
-    is => 'ro',
+    is => 'rw',
     isa => 'Str|ArrayRef[Str]',
     default => sub { [] },
     required => 0,
@@ -190,12 +190,22 @@ sub load_phrasebooks {
 }
 
 # finds the path of Phrasebooks within the Library leading to Personality
-# FIXME: *sniff* *sniff* this code seems a bit whiffy
 use Path::Class;
 sub _find_phrasebooks {
     my $self = shift;
-    my @libs = (ref $self->add_library ? @{$self->add_library} : ($self->add_library));
-    push @libs, (ref $self->library ? @{$self->library} : ($self->library));
+    my @libs = (ref $self->library ? @{$self->library} : ($self->library));
+    my @alib = (ref $self->add_library ? @{$self->add_library} : ($self->add_library));
+
+    my @phrasebooks =
+        ( $self->_walk_find_files(@libs), $self->_walk_find_files(@alib) );
+
+    confess (sprintf "Personality [%s] contains no phrasebook files!\n",
+            $self->personality) unless scalar @phrasebooks;
+    return @phrasebooks;
+}
+
+sub _walk_find_files {
+    my ($self, @libs) = @_;
 
     my $target = undef;
     foreach my $l (@libs) {
@@ -205,22 +215,18 @@ sub _find_phrasebooks {
         });
         last if $target;
     }
-    confess (sprintf "couldn't find Personality '%s' within your Library\n",
-            $self->personality) unless $target;
+    return () unless defined $target;
 
-    my @phrasebooks = ();
+    my @files = ();
     my $root = Path::Class::Dir->new($target->is_absolute ? '' : ());
     foreach my $part ( $target->dir_list ) {
         $root = $root->subdir($part);
         next if scalar grep { $root->subsumes($_) } @libs;
-        push @phrasebooks,
+        push @files,
             sort {$a->basename cmp $b->basename}
             grep { not $_->is_dir } $root->children(no_hidden => 1);
     }
-
-    confess (sprintf "Personality [%s] contains no content!\n",
-            $self->personality) unless scalar @phrasebooks;
-    return @phrasebooks;
+    return @files;
 }
 
 1;
@@ -237,7 +243,7 @@ Net::CLI::Interact::Phrasebook - Load command phrasebooks from a Library
 
 =head1 VERSION
 
-version 1.111590
+version 1.112190
 
 =head1 DESCRIPTION
 
